#[non_exhaustive]pub struct Collision {
pub index_a: usize,
pub index_b: usize,
pub overlap_rect: [f32; 4],
pub overlap_area: f32,
}Expand description
A pair of overlapping PlacedBoxes returned by detect_collisions.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.index_a: usizeIndex of the first box in the input slice.
index_b: usizeIndex of the second box in the input slice.
overlap_rect: [f32; 4]The intersection rectangle [x, y, width, height].
overlap_area: f32Pre-computed area of overlap_rect in PDF points².
Equals overlap_rect[2] * overlap_rect[3]. Callers can use this directly
without recomputing to decide collision severity.